@@ -1,6 +1,6 @@
 /*
  * tst_accessors.c - self-tests for libpskc accessor functions
- * Copyright (C) 2012-2024 Simon Josefsson
+ * Copyright (C) 2012-2025 Simon Josefsson
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -13,9 +13,8 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301 USA
+ * License along with this library; if not, see
+ * <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -26,7 +25,7 @@
 #include <stdio.h>
 #include <string.h>
 
-const char *pskc_all =
+static const char *pskc_all =
   "<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
   "<KeyContainerX Version=\"42.17\" Id=\"KCID\" foo=\"bar\""
   "              xmlns=\"urn:ietf:params:xml:ns:keyprov:pskc\">"
