@@ -1,6 +1,6 @@
 /*
  * tst_validate.c - self-tests for libpskc validation functions
- * Copyright (C) 2012-2024 Simon Josefsson
+ * Copyright (C) 2012-2025 Simon Josefsson
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -13,9 +13,8 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301 USA
+ * License along with this library; if not, see
+ * <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -26,7 +25,7 @@
 #include <stdio.h>
 #include <string.h>
 
-const char *pskc_mini =
+static const char *pskc_mini =
   "<?xml version=\"1.0\"?>\n"
   "<KeyContainer xmlns=\"urn:ietf:params:xml:ns:keyprov:pskc\"\n"
   "              Version=\"1.0\">\n" "  <KeyPackage/>\n" "</KeyContainer>\n";
