@@ -1,7 +1,7 @@
 #!/bin/sh
 
 # tst_oathtool.sh - test that oathtool works
-# Copyright (C) 2009-2024 Simon Josefsson
+# Copyright (C) 2009-2025 Simon Josefsson
 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -40,8 +40,8 @@ dotest()
 	cmp="!="
     fi
 
-    got="$(printf "$STDIN" | $OATHTOOL $params 2> /dev/null | sed 's/\r//')"
-    err="$(printf "$STDIN" | $OATHTOOL $params 2>&1 > /dev/null | sed 's/\r//')"
+    got="$(printf "$STDIN" | $OATHTOOL $params 2> /dev/null | tr -d '\r')"
+    err="$(printf "$STDIN" | $OATHTOOL $params 2>&1 > /dev/null | tr -d '\r')"
 
     if test "`echo $got`" $cmp "`echo $expect`"; then
 	echo FAIL: oathtool $params
@@ -209,7 +209,7 @@ dotest "--base32 @$tmpfile @$tmpfile2" "0"
 echo 993210 >> "$tmpfile"
 dotest "--base32 @$tmpfile @$tmpfile" "0"
 
-# https://gitlab.com/oath-toolkit/oath-toolkit/-/issues/41
+# https://codeberg.org/oath-toolkit/oath-toolkit/issues/41
 # v2.6.10 regression: invalid base32 encoded string
 dotest "--base32 XBK55CIOSR2TO6VUZX7KB2NJX2" "386584"
 
